==> jc-1.4.0.tar.gz: java/util/AbstractList__24RandomAccessSubList.h <==
// final class java.util.AbstractList$RandomAccessSubList

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class a186305a48254cf3 java_util_AbstractList__24RandomAccessSubList
// @dep_class 2e12331367671a95 java_util_AbstractList__24SubList

// header file dependencies
// @dep_header java_util_AbstractList__24SubList

#include "java/util/AbstractList__24SubList.h"

#ifndef _JC_java_util_AbstractList__24RandomAccessSubList_H_
#define _JC_java_util_AbstractList__24RandomAccessSubList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_AbstractList$object;

// Typedefs
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_refs	_jc_java_util_AbstractList__24RandomAccessSubList$sub_refs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs	_jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$refs	_jc_java_util_AbstractList__24RandomAccessSubList$refs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$nonrefs	_jc_java_util_AbstractList__24RandomAccessSubList$nonrefs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$object	_jc_java_util_AbstractList__24RandomAccessSubList$object;

typedef const struct _jc_java_util_AbstractList__24RandomAccessSubList$vmethods	_jc_java_util_AbstractList__24RandomAccessSubList$vmethods;
typedef const struct _jc_java_util_AbstractList__24RandomAccessSubList$vtable	_jc_java_util_AbstractList__24RandomAccessSubList$vtable;
typedef const struct _jc_java_util_AbstractList__24RandomAccessSubList$vtype	_jc_java_util_AbstractList__24RandomAccessSubList$vtype;

// Constructors
extern void _jc_java_util_AbstractList__24RandomAccessSubList$method$_init$67d4a8f69e5f2e87(_jc_env *, struct _jc_java_util_AbstractList__24RandomAccessSubList$object *, struct _jc_java_util_AbstractList$object *, jint, jint);

// Virtual methods structure
struct _jc_java_util_AbstractList__24RandomAccessSubList$vmethods {
};

// Vtable
struct _jc_java_util_AbstractList__24RandomAccessSubList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_AbstractList__24SubList$vmethods	java_util_AbstractList__24SubList;
	_jc_java_util_AbstractList__24RandomAccessSubList$vmethods	java_util_AbstractList__24RandomAccessSubList;
};

// Vtype
struct _jc_java_util_AbstractList__24RandomAccessSubList$vtype {
	_jc_type			type;
	_jc_java_util_AbstractList__24RandomAccessSubList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_AbstractList__24RandomAccessSubList$refs {
    _jc_java_util_AbstractList__24RandomAccessSubList$sub_refs	java_util_AbstractList__24RandomAccessSubList;
    _jc_java_util_AbstractList__24SubList$sub_refs	java_util_AbstractList__24SubList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractList__24RandomAccessSubList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_AbstractList__24SubList$sub_nonrefs	java_util_AbstractList__24SubList;
    _jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs	java_util_AbstractList__24RandomAccessSubList;
};

// Object instance structure
struct _jc_java_util_AbstractList__24RandomAccessSubList$object {
	_jc_java_util_AbstractList__24RandomAccessSubList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractList__24RandomAccessSubList$vtype	*vtype;
	_jc_java_util_AbstractList__24RandomAccessSubList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractList__24RandomAccessSubList$vtype _jc_java_util_AbstractList__24RandomAccessSubList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractList__24RandomAccessSubList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractList__24RandomAccessSubList$class_object;

#endif	/* _JC_java_util_AbstractList__24RandomAccessSubList_H_ */

==> jc-1.4.6.tar.gz: java/util/AbstractList__24RandomAccessSubList.h <==
// final class java.util.AbstractList$RandomAccessSubList

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class f5238436362828db java_util_AbstractList
// @dep_class a186305a48254cf3 java_util_AbstractList__24RandomAccessSubList
// @dep_class 2e12331367671a95 java_util_AbstractList__24SubList

// header file dependencies
// @dep_header java_util_AbstractList__24SubList

#include "java/util/AbstractList__24SubList.h"

#ifndef _JC_java_util_AbstractList__24RandomAccessSubList_H_
#define _JC_java_util_AbstractList__24RandomAccessSubList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_AbstractList$object;

// Typedefs
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_refs	_jc_java_util_AbstractList__24RandomAccessSubList$sub_refs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs	_jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$refs	_jc_java_util_AbstractList__24RandomAccessSubList$refs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$nonrefs	_jc_java_util_AbstractList__24RandomAccessSubList$nonrefs;
typedef struct _jc_java_util_AbstractList__24RandomAccessSubList$object	_jc_java_util_AbstractList__24RandomAccessSubList$object;

typedef const struct _jc_java_util_AbstractList__24RandomAccessSubList$vmethods	_jc_java_util_AbstractList__24RandomAccessSubList$vmethods;
typedef const struct _jc_java_util_AbstractList__24RandomAccessSubList$vtable	_jc_java_util_AbstractList__24RandomAccessSubList$vtable;
typedef const struct _jc_java_util_AbstractList__24RandomAccessSubList$vtype	_jc_java_util_AbstractList__24RandomAccessSubList$vtype;

// Constructors
extern void _jc_java_util_AbstractList__24RandomAccessSubList$method$_init$67d4a8f69e5f2e87(_jc_env *, struct _jc_java_util_AbstractList__24RandomAccessSubList$object *, struct _jc_java_util_AbstractList$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_AbstractList__24RandomAccessSubList$vmethods {
};

// Vtable
struct _jc_java_util_AbstractList__24RandomAccessSubList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractList$vmethods	java_util_AbstractList;
	_jc_java_util_AbstractList__24SubList$vmethods	java_util_AbstractList__24SubList;
	_jc_java_util_AbstractList__24RandomAccessSubList$vmethods	java_util_AbstractList__24RandomAccessSubList;
};

// Vtype
struct _jc_java_util_AbstractList__24RandomAccessSubList$vtype {
	_jc_type			type;
	_jc_java_util_AbstractList__24RandomAccessSubList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_AbstractList__24RandomAccessSubList$refs {
    _jc_java_util_AbstractList__24RandomAccessSubList$sub_refs	java_util_AbstractList__24RandomAccessSubList;
    _jc_java_util_AbstractList__24SubList$sub_refs	java_util_AbstractList__24SubList;
    _jc_java_util_AbstractList$sub_refs	java_util_AbstractList;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractList__24RandomAccessSubList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractList$sub_nonrefs	java_util_AbstractList;
    _jc_java_util_AbstractList__24SubList$sub_nonrefs	java_util_AbstractList__24SubList;
    _jc_java_util_AbstractList__24RandomAccessSubList$sub_nonrefs	java_util_AbstractList__24RandomAccessSubList;
};

// Object instance structure
struct _jc_java_util_AbstractList__24RandomAccessSubList$object {
	_jc_java_util_AbstractList__24RandomAccessSubList$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractList__24RandomAccessSubList$vtype	*vtype;
	_jc_java_util_AbstractList__24RandomAccessSubList$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractList__24RandomAccessSubList$vtype _jc_java_util_AbstractList__24RandomAccessSubList$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractList__24RandomAccessSubList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractList__24RandomAccessSubList$class_object;

#endif	/* _JC_java_util_AbstractList__24RandomAccessSubList_H_ */
